#[repr(C, packed(1))]pub struct StructureInfo {
pub id: u32,
pub name: PaddedString<MAX_NAME_LENGTH>,
pub construction_progress: u32,
pub upgrade_progress: u32,
pub button_art: PaddedString<MAX_BUTTON_ART_LENGTH>,
}Expand description
State for a single structure owned by a player.
Fields
id: u32Game-internal structure ID.
name: PaddedString<MAX_NAME_LENGTH>Display name.
construction_progress: u32Build progress towards completion, as a percentage e.g. 25 -> 25%
upgrade_progress: u32Build progress of an upgrade affecting this structure, as a percentage e.g. Town Hall -> Keep
Path to the structure’s button icon.