UpgradeInfo

Struct UpgradeInfo 

#[repr(C, packed(1))]
pub struct UpgradeInfo { pub id: u32, pub name: PaddedString<MAX_NAME_LENGTH>, pub current_level: u32, pub max_level: u32, pub upgrade_progress: u32, pub button_art: PaddedString<MAX_BUTTON_ART_LENGTH>, }
State for a single upgrade or research entry available to a player.

Fields

id: u32

Game-internal upgrade ID.

name: PaddedString<MAX_NAME_LENGTH>

Display name.

current_level: u32

Currently researched level.

max_level: u32

Maximum level this upgrade supports.

upgrade_progress: u32

Progress towards the next level, as a percentage e.g. 25 -> 25%.

button_art: PaddedString<MAX_BUTTON_ART_LENGTH>

Path to the upgrade’s button icon.